{% extends "flask_debug/base.html" %}

{% block container %}
    {{super()}}
        <h1>Configuration for {{g.app.name}}</h1>
        <table class="table table-striped table-hover">
            <tr>
                <th>Key</th>
                <th>Value</th>
            </tr>
        {% for key, value in config.items()|sort %}
            <tr>
                <td>{{key}}</td>
                <td>{{'%r'|format(value)}}</td>
            </tr>
        {% endfor %}
        </table>
{% endblock %}
