{% extends g.bootstrap_base_template %}

{% block title %}{{g.menu[request.endpoint]|default('flask-debug')}}: {{g.app .name}}{% endblock %}


{% block content %}
<div class="container" style="margin-top: 1em;">
{% block container %}
  <ul class="nav nav-tabs">
  {% for endpoint, name in g.menu.items() %}
      <li{% if request.endpoint == endpoint %} class="active"{% endif %}>
          <a href="{{url_for(endpoint)}}">{{name}}</a>
      </li>
  {% endfor %}
  </ul>
{% endblock container %}
</div>
{% endblock content %}
