{# this is a minimal bootstrap template in case Flask-Bootstrap is not installed -#}

<html>
<head>
    <!-- using built-in bootstrap template -->
    {% block head %}
    <link rel="stylesheet" href="//netdna.bootstrapcdn.com/bootstrap/latest/css/bootstrap.min.css">
    <link rel="stylesheet" href="//netdna.bootstrapcdn.com/bootstrap/latest/css/bootstrap-theme.min.css">
    {% endblock %}
    <title>{% block title %}{% endblock %}</title>

</head>
<body>
{% block body -%}
{% block content %}{% endblock %}

{% block scripts %}
<script src="//cdnjs.cloudflare.com/ajax/libs/jquery/1.11.0/jquery.js"></script>
<script src="//netdna.bootstrapcdn.com/bootstrap/latest/js/bootstrap.min.js"></script>
{% endblock %}

{%- endblock body %}
</body>
</html>
